#
# spec file for package ghc-mono-traversable
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name mono-traversable
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.0.21.0
Release:        1.8
Summary:        Type classes for mapping, folding, and traversing monomorphic containers
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-hashable-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-split-devel
BuildRequires:  ghc-split-prof
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-unordered-containers-prof
BuildRequires:  ghc-vector-algorithms-devel
BuildRequires:  ghc-vector-algorithms-prof
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-vector-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-HUnit-prof
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-foldl-devel
BuildRequires:  ghc-foldl-prof
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-prof
%endif

%description
Type classes for mapping, folding, and traversing monomorphic containers.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Fri Dec 13 2024 Peter Simons <psimons@suse.com>
- Update mono-traversable to version 1.0.21.0.
  [#]# 1.0.21.0
  * Support for vector 0.13.2.0, adding instances for [`Data.Vector.Strict`](https://hackage.haskell.org/package/vector-0.13.2.0/docs/Data-Vector-Strict.html) data structure.
    [#244](https://github.com/snoyberg/mono-traversable/issues/244)
* Fri Sep 13 2024 Peter Simons <psimons@suse.com>
- Update mono-traversable to version 1.0.20.0.
  [#]# 1.0.20.0
  * Added instances for [`Reverse`](https://hackage.haskell.org/package/transformers-0.6.1.1/docs/Data-Functor-Reverse.html#t:Reverse) data structure.
  [#]# 1.0.19.1
  * Removed 'highly experimental' warning haddock comment from Data.Containers.
  [#]# 1.0.19.0
  * Added `filterWithKey` to `IsMap`.
    [#232](https://github.com/snoyberg/mono-traversable/pull/232)
  [#]# 1.0.18.0
  * Added MonoPointed instance for text Builder
    [#225](https://github.com/snoyberg/mono-traversable/pull/225)
* Wed Feb 28 2024 Peter Simons <psimons@suse.com>
- Update mono-traversable to version 1.0.17.0.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/mono-traversable-1.0.17.0/src/ChangeLog.md
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Mon Sep 27 2021 psimons@suse.com
- Update mono-traversable to version 1.0.15.3.
  [#]# 1.0.15.3
  * Compile with GHC 9.2 (`Option` removed from `base-4.16`)
    [#199](https://github.com/snoyberg/mono-traversable/issues/199)
* Wed Sep 22 2021 psimons@suse.com
- Update mono-traversable to version 1.0.15.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Sep 20 2021 psimons@suse.com
- Update mono-traversable to version 1.0.15.2.
  [#]# 1.0.15.2
  * Support transformers 0.6.0.0 [#196](https://github.com/snoyberg/mono-traversable/issues/196)
  * Compile with GHC 9 [#193](https://github.com/snoyberg/mono-traversable/pull/193)
* Wed Aug  4 2021 psimons@suse.com
- Update mono-traversable to version 1.0.15.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Sun Dec 29 2019 psimons@suse.com
- Update mono-traversable to version 1.0.15.1.
  [#] ChangeLog for mono-traversable
  [#]# 1.0.15.1
  * Remove whitespace after `@` in as-patterns for GHC HEAD [#186](https://github.com/snoyberg/mono-traversable/pull/186)
  [#]# 1.0.15.0
  * Added `toNonEmpty` to `Data.NonNull`
    [#185](https://github.com/snoyberg/mono-traversable/pull/185)
  [#]# 1.0.14.0
  * Added `WrappedMono` to `Data.MonoTraversable`
    [#182](https://github.com/snoyberg/mono-traversable/pull/182)
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Fri Oct  4 2019 psimons@suse.com
- Update mono-traversable to version 1.0.13.0.
  [#]# 1.0.13.0
  * Added `WrappedPoly` to `Data.MonoTraversable`
    [#180](https://github.com/snoyberg/mono-traversable/pull/180)
* Thu Aug 15 2019 psimons@suse.com
- Update mono-traversable to version 1.0.12.0.
  [#]# 1.0.12.0
  * Added `filterSet` to `Data.Containers`
  * Use container specific implementations for `filterSet` and `filterMap`
    [#178](https://github.com/snoyberg/mono-traversable/pull/178)
* Sun Feb  3 2019 psimons@suse.com
- Update mono-traversable to version 1.0.11.0.
  [#]# 1.0.11.0
  * Adding monomorphic instances for GHC.Generics and Data.Proxy types
    [#175](https://github.com/snoyberg/mono-traversable/issues/175)
* Fri Dec 21 2018 psimons@suse.com
- Update mono-traversable to version 1.0.10.0.
  [#]# 1.0.10.0
  * Make index work on negative indices
    [#172](https://github.com/snoyberg/mono-traversable/issues/172)
    [#114](https://github.com/snoyberg/mono-traversable/issues/114)
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Thu Aug  2 2018 psimons@suse.com
- Update mono-traversable to version 1.0.9.0.
  [#]# 1.0.9.0
  * Added `filterMap` to `Data.Containers`
    [#167](https://github.com/snoyberg/mono-traversable/pull/167)
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update mono-traversable to version 1.0.8.1.
  * Compat with gauge 0.1 and 0.2
  * Switch to gauge
  * Relax constraint on `singleton` to `MonoPointed`
    [#156](https://github.com/snoyberg/mono-traversable/issues/156)
  * Add `dropPrefix` and `dropSuffix` to `Data.Sequences` [#139](https://github.com/snoyberg/mono-traversable/issues/139)
  * Change `sort` implementation [#153](https://github.com/snoyberg/mono-traversable/issues/153)
  * Add `mapNonNull` function to `Data.NonNull` [#150](https://github.com/snoyberg/mono-traversable/issues/150)
  * Move `oelem` and `onotElem` into the `MonoFoldable` class [#133](https://github.com/snoyberg/mono-traversable/issues/133)
  * Change `instance MonoFoldable (Set e)` to `instance Ord e => MonoFoldable (Set e)`
  * Add `dropEnd` function to the `IsSequence` class, and a specialized implementation for `Text`
  * Add `ensurePrefix` and `ensureSuffix` functions [#141](https://github.com/snoyberg/mono-traversable/pull/141)
  * Fix test suite for foldl 1.3
* Tue Mar  7 2017 psimons@suse.com
- Update to version 1.0.2 with cabal2obs.
* Mon Feb 27 2017 psimons@suse.com
- Update to version 1.0.1.3 with cabal2obs.
* Mon Feb 20 2017 psimons@suse.com
- Update to version 1.0.1.2 with cabal2obs.
* Thu Jan 26 2017 psimons@suse.com
- Update to version 1.0.1.1 with cabal2obs.
* Mon Jan 16 2017 psimons@suse.com
- Update to version 1.0.1 revision 1 with cabal2obs.
* Mon Sep 26 2016 psimons@suse.com
- Update to version 1.0.1 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 1.0.0.1 revision 1 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.10.2 revision 0 with cabal2obs.
* Wed Apr 13 2016 mimi.vx@gmail.com
- update to 0.10.2
  * Add delete and deleteBy methods to EqSequence
* Tue Feb 16 2016 mimi.vx@gmail.com
- update to 0.10.1.1
  * Remove unneeded INLINEs
* Tue Jan 26 2016 mimi.vx@gmail.com
- update to 0.10.1
  * Allow comonad-5
* Tue Dec 15 2015 mimi.vx@gmail.com
- update to 0.10.0.1
  * Remove Functor instance for MinLen
  * Instance for Data.Sequence.Seq is incorrect.
* Tue Nov 17 2015 mimi.vx@gmail.com
- initial commit
